@@ -14,6 +14,11 @@ def get_child_nodes(node_parent, node_tag, node_att_name=None, node_att_val=None
     return find_all_nodes(node_parent, node_tag, node_att_name, node_att_val, recursive=False)
 
 
+# will search in all of the direct children of the root
+def get_root_direct_child_nodes(xml_file, node_tag, node_att_name=None, node_att_val=None):
+    return get_child_nodes(get_root_node(xml_file), node_tag, node_att_name, node_att_val)
+
+
 # will return a list of nodes which doesn't have a specific attribute
 def get_nodes_from_xml_without_att(xml_file, node_tag, node_att_name=None):
     root = xml_file.getroot()
@@ -86,7 +91,7 @@ def get_node_att(node, att_name):
 def read_xml_file(xml_path, namespace_dict=None):
     xml = et.parse(xml_path)
     if namespace_dict:
-        for prefix, uri in namespace_dict:
+        for prefix, uri in namespace_dict.items():
             et.register_namespace(prefix, uri)
     return xml
 
